Juniper.SRCPE
=============

====== =============================================
Vendor `Juniper Networks <http://www.juniper.net/>`_
OS     SRCPE
====== =============================================

Juniper.SRCPE profile supports SRC-PE family of policy servers and controllers

Tested Equipment
----------------
.. supported:: Juniper.SRCPE
